@@ -1064,6 +1064,14 @@ private:
                                            Alter_inplace_info *ha_alter_info);
   bool wrapper_inplace_alter_table(TABLE *altered_table,
                                    Alter_inplace_info *ha_alter_info);
+  bool storage_inplace_alter_table_index(TABLE *altered_table,
+                                         Alter_inplace_info *ha_alter_info);
+  bool storage_inplace_alter_table_add_column(TABLE *altered_table,
+                                              Alter_inplace_info *ha_alter_info);
+  bool storage_inplace_alter_table_drop_column(TABLE *altered_table,
+                                               Alter_inplace_info *ha_alter_info);
+  bool storage_inplace_alter_table_rename_column(TABLE *altered_table,
+                                                 Alter_inplace_info *ha_alter_info);
   bool storage_inplace_alter_table(TABLE *altered_table,
                                    Alter_inplace_info *ha_alter_info);
   bool wrapper_commit_inplace_alter_table(TABLE *altered_table,
